@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import logging
+import sys
 from enum import Enum, IntEnum
 from pathlib import Path
 from itertools import chain
@@ -133,8 +134,15 @@ TEMPLATES_LUSER = Path('~/.local/share').expanduser()
 TEMPLATES_LOCATIONS = [
     TEMPLATES_LGLOBAL.joinpath(PROJECT_NAME, 'templates'),
     TEMPLATES_LUSER.joinpath(PROJECT_NAME, 'templates'),
-    res.files('pythumbnailer').__enter__() / 'templates',  # Current module Folder
 ]
+if sys.version_info >= (3, 9):
+    TEMPLATES_LOCATIONS.append(
+        res.files('pythumbnailer').__enter__() / 'templates',  # Current module Folder
+    )
+else:
+    TEMPLATES_LOCATIONS.append(
+        Path(__file__).resolve().parent / 'templates',  # Current installation Folder
+    )
 
 
 def template_locations(*override: Path):
@@ -188,6 +196,8 @@ class ThumbnailData:
     original: Path
     title: str  # Image "title", description, whatever you want to call it
     time: TimePoint
+    mime: str  # Thumbnail MIME type
+    omime: str = None  # Original MIME type
     size: Resolution = None
 
 
